@@ -14,6 +14,12 @@
 #ifndef MIN_VERSION_vector
 #define MIN_VERSION_vector(x,y,z) 1
 #endif
+
+#ifndef MIN_VERSION_transformers
+#define MIN_VERSION_transformers(x,y,z) 1
+#endif
+
+
 -----------------------------------------------------------------------------
 -- |
 -- Copyright   :  (C) 2012-2015 Edward Kmett
@@ -33,6 +39,7 @@ module Linear.V2
   , ex, ey
   , perp
   , angle
+  , crossZ
   ) where
 
 import Control.Applicative
@@ -385,6 +392,14 @@ instance MonadFix V2 where
 angle :: Floating a => a -> V2 a
 angle a = V2 (cos a) (sin a)
 
+-- | The Z-component of the cross product of two vectors in the XY-plane.
+--
+-- >>> crossZ (V2 1 0) (V2 0 1)
+-- 1
+crossZ :: Num a => V2 a -> V2 a -> a
+crossZ (V2 x1 y1) (V2 x2 y2) = x1*y2 - y1*x2
+{-# INLINE crossZ #-}
+
 instance Bounded a => Bounded (V2 a) where
   minBound = pure minBound
   {-# INLINE minBound #-}
@@ -410,7 +425,18 @@ instance Serialize a => Serialize (V2 a) where
   put = serializeWith Cereal.put
   get = deserializeWith Cereal.get
 
+#if (MIN_VERSION_transformers(0,5,0)) || !(MIN_VERSION_transformers(0,4,0))
+instance Eq1 V2 where
+  liftEq f (V2 a b) (V2 c d) = f a c && f b d
+instance Ord1 V2 where
+  liftCompare f (V2 a b) (V2 c d) = f a c `mappend` f b d
+instance Read1 V2 where
+  liftReadsPrec f _ = readsData $ readsBinaryWith f f "V2" V2
+instance Show1 V2 where
+  liftShowsPrec f _ d (V2 a b) = showsBinaryWith f f "V2" d a b
+#else
 instance Eq1 V2 where eq1 = (==)
 instance Ord1 V2 where compare1 = compare
 instance Show1 V2 where showsPrec1 = showsPrec
 instance Read1 V2 where readsPrec1 = readsPrec
+#endif
